@@ -4,7 +4,7 @@ from django.conf.urls import patterns, url
 from controller.admin.utils import action_to_view, set_default_filter
 from controller.utils.singletons.admin import SingletonModelAdmin
 
-from .helpers import FuncAttrWrapper
+from .helpers import FuncAttrWrapper, SortableField
 
 
 class AddOrChangeInlineForm(admin.options.InlineModelAdmin):
@@ -109,3 +109,66 @@ class ChangeListDefaultFilter(object):
         if hasattr(response, 'context_data') and 'cl' in response.context_data:
             response.context_data['cl'].default_changelist_filters = defaults
         return response
+
+class SortableTabularInline(admin.options.TabularInline):
+    """ 
+        Inline that provides sortable functionallity
+        Supports field override for related object attribute sort
+        e.g. sortable_fields = {'node': 'node__name'} should replace
+        sort by node id with sort by node name.
+        Example usage:
+        class SliverInline(PermissionTabularInline, SortableTabularInline):
+            sortable_fields = {'node_link':'node__name'}
+    """
+    template = "admin/controller/edit_inline/tabular.html"
+    sortable_fields = {} # optional field that allows override sorting
+
+    def get_ordering(self, request):
+        """ Define dynamic ordering based on request parameters """
+        sortable_fields = self.get_sortable_fields(request)
+        #### TODO: how to insert as extra_context and avoid using session??
+        request.session['sortable_fields'] = sortable_fields
+        ordering = request.GET.get('o')
+        try:
+            # check user input
+            column = abs(int(ordering))
+            current_sfield = sortable_fields[column]
+        except (IndexError, TypeError, ValueError) as e:
+            return self.ordering # default ordering or None
+
+        current_sfield.update(ordering)
+        return [current_sfield.sort_by()]
+
+    def get_sortable_fields(self, request):
+        """ 
+            Hack for get the inline fields SHOWED at admin page 
+            NOTE: excludes primary key and hidden foreign key
+            Returns SortableFields list
+        """
+        sortable_fields = []
+
+        if self.fields:
+            # generated admin fields cannot be selected as sort column
+            for field in self.fields:
+                sortable = field in self.model._meta.fields
+                sortable_field = SortableField(field, len(sortable_fields), sortable)
+                # insert overrides
+                if field in self.sortable_fields:
+                    sortable_field.name = self.sortable_fields.get(field)
+                    sortable_field.sortable = True
+                sortable_fields.append(sortable_field)
+            return sortable_fields
+
+        for field in self.model._meta.fields:
+            if field.get_internal_type() == "ForeignKey":
+                if field.rel.to is self.parent_model:
+                    continue
+            elif field.get_internal_type() == "AutoField":
+                continue
+            sortable_field = SortableField(field.name, len(sortable_fields))
+            # insert overrides
+            sortable_field.name = self.sortable_fields.get(field.name, field.name)
+            sortable_fields.append(sortable_field)
+        
+        return sortable_fields
+
