@@ -5,11 +5,12 @@ from django.core.exceptions import ImproperlyConfigured
 from django.db import models
 from django.utils.timezone import now
 
-from communitynetworks import settings
 from controller.models.fields import URIField
 from controller.utils import is_installed
 from nodes.models import Node, Server
 
+from . import settings
+
 
 # Hook Community Network support for related models
 # This must be at the begining in order to avoid wired import problems
