@@ -18,12 +18,12 @@ from controller.admin.utils import (admin_link, get_admin_link, colored, wrap_ad
     display_timesince)
 from permissions.admin import PermissionTabularInline, PermissionModelAdmin
 
-from issues.actions import (reject_tickets, resolve_tickets, take_tickets,
-    close_tickets, mark_as_unread, mark_as_read, set_default_queue)
-from issues.filters import MyTicketsListFilter, TicketStateListFilter
-from issues.forms import MessageInlineForm, TicketForm
-from issues.helpers import get_ticket_changes, markdown_formated_changes, filter_actions
-from issues.models import Ticket, Queue, Message
+from .actions import (reject_tickets, resolve_tickets, take_tickets,close_tickets,
+    mark_as_unread, mark_as_read, set_default_queue)
+from .filters import MyTicketsListFilter, TicketStateListFilter
+from .forms import MessageInlineForm, TicketForm
+from .helpers import get_ticket_changes, markdown_formated_changes, filter_actions
+from .models import Ticket, Queue, Message
 
 
 PRIORITY_COLORS = { 
@@ -143,7 +143,7 @@ class TicketAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdm
     )
     date_hierarchy = 'created_on'
     search_fields = [
-        'id', 'subject', 'created_by__username', 'created_by__email', 'queue',
+        'id', 'subject', 'created_by__username', 'created_by__email', 'queue__name',
         'owner__username'
     ]
     actions = [
@@ -186,10 +186,10 @@ class TicketAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdm
     
     class Media:
         css = {
-            'all': ('issues/css/admin-ticket.css',)
+            'all': ('issues/css/ticket-admin.css',)
         }
         js = (
-            'issues/js/admin-ticket.js',
+            'issues/js/ticket-admin.js',
         )
     
     def display_summary(self, ticket):
