@@ -12,15 +12,17 @@ PING_INSTANCES = getattr(settings, 'PING_INSTANCES', (
         'model': 'tinc.TincClient',
         'admin_classes': (
             ('TincClientInline', 'tinc_compatible_address', '', 'content_object'),
-            ('HostAdmin', 'address', 'tinc', ''),),
+            ('HostAdmin', 'address', 'tinc', ''),
+        ),
         'app': 'mgmtnetworks.tinc',
         'schedule': 200,
         'expire_window': 150,
-        'get_addr': lambda obj: getattr(obj, 'address') },
-    {
+        'get_addr': lambda obj: getattr(obj, 'address') 
+    }, {
         'model': 'slices.SliverIface',
         'admin_classes': (
-            ('SliverIfaceInline', 'ipv6_addr', '', 'sliver'),),
+            ('SliverIfaceInline', 'ipv6_addr', '', 'sliver'),
+        ),
         'app': 'slices',
         'schedule': 200,
         'expire_window': 150,
