@@ -1,7 +1,7 @@
+import hashlib
 import inspect
 import os
 import tempfile
-from hashlib import sha256
 
 from django_transaction_signals import defer
 from django.conf import settings as project_settings
@@ -22,6 +22,7 @@ from nodes.settings import NODES_NODE_ARCHS
 
 from . import settings
 from .exceptions import VlanAllocationError, IfaceAllocationError
+from .helpers import save_files_with_pk_value
 from .tasks import force_slice_update, force_sliver_update
 
 
@@ -95,7 +96,7 @@ class Template(models.Model):
     @property
     def image_sha256(self):
         try:
-            return sha256(self.image.file.read()).hexdigest()
+            return hashlib.sha256(self.image.file.read()).hexdigest()
         except:
             return None
 
@@ -153,10 +154,28 @@ class Slice(models.Model):
             help_text='The SHA256 hash of the exp_data file, used to check its integrity. '
                       'Compulsory when a file has been specified.',
             validators=[validate_sha256])
+    overlay = models.FileField(blank=True,
+            upload_to=make_upload_to('overlay', settings.SLICES_SLICE_OVERLAY_DIR,
+                                     settings.SLICES_SLICE_OVERLAY_NAME,),
+            help_text='File containing overlay for slivers (if they do not explicitly '
+                      'indicate one)',
+            validators=[validate_file_extensions(settings.SLICES_SLICE_OVERLAY_EXTENSIONS)])
+    overlay_uri = models.CharField('overlay URI', max_length=256, blank=True,
+            help_text='The URI of a file containing an overlay for slivers (if they '
+                      'do not explicitly indicate one). The file must be an archive '
+                      '(e.g. a .tar.gz) of the upper directory of an overlayfs filesystem, '
+                      'and will be applied on top of the used template. This member '
+                      'may be set directly or through the do-upload-overlay function.')
+    overlay_sha256 = models.CharField('overlay SHA256', max_length=64, blank=True,
+            help_text='The SHA256 hash of the previous file, used to check its integrity. '
+                      'This member may be set directly or through the do-upload-overlay '
+                      'function. Compulsory when a file has been specified.',
+            validators=[validate_sha256])
     set_state = models.CharField(max_length=16, choices=STATES, default=REGISTER,
-            help_text='The state set on this slice (set state) and its slivers (if they '
-                      'do not explicitly indicate one). Possible values: register (initial), '
-                      'deploy, start. See <a href="https://wiki.confine-project.eu/arch:'
+            help_text='The state set on this slice (set state) and its slivers '
+                      '(if they do not explicitly indicate a lower one). '
+                      'Possible values: register (initial), &lt; deploy &lt; start. '
+                      'See <a href="https://wiki.confine-project.eu/arch:'
                       'slice-sliver-states">slice and sliver states</a> for the full '
                       'description of set states and possible transitions.')
     template = models.ForeignKey(Template,
@@ -185,29 +204,28 @@ class Slice(models.Model):
         self.update_set_state(commit=False)
         if not self.pk:
             self.expires_on = now() + settings.SLICES_SLICE_EXP_INTERVAL
-            if self.exp_data:
-                # Dirty hack in order to allow pk values on exp_data filename
-                exp_data = self.exp_data
-                self.exp_data = None
-                super(Slice, self).save(*args, **kwargs)
-                self.exp_data = exp_data
+            save_files_with_pk_value(self, ('exp_data', 'overlay'), *args, **kwargs)
         super(Slice, self).save(*args, **kwargs)
     
     def clean(self):
         super(Slice, self).clean()
-        if self.exp_data:
-            if self.exp_data_uri:
-                raise ValidationError('exp_data or exp_data_uri ?')
-            self.exp_data_sha256 = sha256(self.exp_data.file.read()).hexdigest()
-        if self.exp_data_uri and not self.exp_data_sha256:
-            raise ValidationError('Missing exp_data_sha256.')
+        for field in ('exp_data', 'overlay'):
+            if getattr(self, field):
+                if getattr(self, field+'_uri'):
+                    raise ValidationError('%s or %s_uri ?' % (field, field))
+                sha256 = hashlib.sha256(getattr(self, field).file.read()).hexdigest()
+                setattr(self, field+'_sha256', sha256)
+            if getattr(self, field+'_uri') and not getattr(self, field+'_sha256'):
+                raise ValidationError('Missing %s_sha256.' % field)
         # clean set_state
         if not self.pk:
             if self.set_state != Slice.REGISTER:
                 raise ValidationError("Initial state must be Register")
         else:
             old = Slice.objects.get(pk=self.pk)
-            if self.vlan_nr != old.vlan_nr and old.set_state != self.REGISTER and self.vlan_nr == '-1':
+            is_register = old.set_state != self.REGISTER
+            vlan_requested = self.vlan_nr == '-1'
+            if self.vlan_nr != old.vlan_nr and is_register and vlan_requested:
                 raise ValidationError("Vlan can not be requested in state != register")
     
     def renew(self):
@@ -293,10 +311,29 @@ class Sliver(models.Model):
             help_text='The SHA256 hash of the exp data file, used to check its integrity. '
                       'Compulsory when a file has been specified.',
             validators=[validate_sha256])
+    overlay = models.FileField(blank=True,
+            upload_to=make_upload_to('overlay', settings.SLICES_SLIVER_OVERLAY_DIR,
+                                     settings.SLICES_SLIVER_OVERLAY_NAME),
+            help_text='File containing overlay for this sliver.',
+            validators=[validate_file_extensions(settings.SLICES_SLIVER_OVERLAY_EXTENSIONS)])
+    overlay_uri = models.CharField('overlay URI', max_length=256, blank=True,
+            help_text='If present, the URI of a file containing an overlay for this '
+                      'sliver, instead of the one specified by the slice. The file '
+                      'must be an archive (e.g. a .tar.gz) of the upper directory '
+                      'of an overlayfs filesystem, and will be applied on top of the '
+                      'used template. This member may be set directly or through the '
+                      'do-upload-overlay function.')
+    overlay_sha256 = models.CharField('overlay SHA256', max_length=64, blank=True,
+            help_text='The SHA256 hash of the previous file, used to check its integrity. '
+                      'This member may be set directly or through the do-upload-overlay '
+                      'function. Compulsory when a file has been specified.',
+            validators=[validate_sha256])
     set_state = NullableCharField(max_length=16, choices=Slice.STATES, blank=True,
-            help_text='If present, the state set on this sliver (set state), instead of '
-                      'the one specified by the slice. Possible values: register (initial), '
-                      'deploy, start. See <a href="https://wiki.confine-project.eu/arch:'
+            help_text='If present, the state set on this sliver (set state), '
+                      'which overrides a higher one specified by the slice '
+                      '(e.g. register overrides start, but start does not override register). '
+                      'Possible values: register (initial) &lt; deploy &lt; start. '
+                      'See <a href="https://wiki.confine-project.eu/arch:'
                       'slice-sliver-states">slice and sliver states</a> for the full '
                       'description of set states and possible transitions.', null=True)
     template = models.ForeignKey(Template, null=True, blank=True,
@@ -313,12 +350,14 @@ class Sliver(models.Model):
     
     def clean(self):
         super(Sliver, self).clean()
-        if self.exp_data:
-            if self.exp_data_uri:
-                raise ValidationError('exp_data or exp_data_uri ?')
-            self.exp_data_sha256 = sha256(self.exp_data.file.read()).hexdigest()
-        if self.exp_data_uri and not self.exp_data_sha256:
-            raise ValidationError('Missing exp_data_sha256.')
+        for field in ('exp_data', 'overlay'):
+            if getattr(self, field):
+                if getattr(self, field+'_uri'):
+                    raise ValidationError('%s or %s_uri ?' % (field, field))
+                sha256 = hashlib.sha256(getattr(self, field).file.read()).hexdigest()
+                setattr(self, field+'_sha256', sha256)
+            if getattr(self, field+'_uri') and not getattr(self, field+'_sha256'):
+                raise ValidationError('Missing %s_sha256.' % field)
         # TODO can slivers be added to slice.set_state != Register?
 #        if self.set_state:
 #            slice = self.slice
@@ -331,12 +370,27 @@ class Sliver(models.Model):
     def save(self, *args, **kwargs):
         if not self.pk:
             self.instance_sn = self.slice.new_sliver_instance_sn
+            save_files_with_pk_value(self, ('exp_data', 'overlay'), *args, **kwargs)
         super(Sliver, self).save(*args, **kwargs)
     
     @property
     def max_num_ifaces(self):
         return 256 # limited by design -> #nr: unsigned 8 bits
     
+    @property
+    def effective_set_state(self):
+        slice = self.slice
+        if slice.set_state == slice.DEPLOY and self.set_state == slice.REGISTER:
+            return self.set_state
+        elif slice.set_state == slice.START and self.set_state in [slice.REGISTER, slice.DEPLOY]:
+            return self.set_state
+        return slice.set_state
+    
+    @property
+    def mgmt_iface(self):
+        iface = self.interfaces.filter(type='management')
+        return iface.get() if iface else None
+    
     def update(self):
         self.instance_sn += 1
         self.save()
