@@ -5,8 +5,10 @@ from django.conf import settings
 
 
 SLICES_TEMPLATE_TYPES = getattr(settings, 'SLICES_TEMPLATE_TYPES', (
-        ('debian6', 'Debian 6'),
-        ('openwrt-backfire', 'OpenWRT Backfire'),
+        ('debian', 'Debian'),
+        ('openwrt', 'OpenWRT'),
+        ('ubuntu', 'Ubuntu'),
+        ('other', 'Other'),
 ))
 
 SLICES_TEMPLATE_TYPE_DFLT = getattr(settings, 'SLICES_TEMPLATE_TYPE_DFLT', 'debian6')
@@ -35,6 +37,14 @@ SLICES_SLICE_EXP_DATA_NAME = getattr(settings, 'SLICES_SLICE_EXP_DATA_NAME',
 SLICES_SLICE_EXP_DATA_EXTENSIONS = getattr(settings, 'SLICES_SLICE_EXP_DATA_EXTENSIONS',
         ('.tar.gz', '.tgz'))
 
+SLICES_SLICE_OVERLAY_DIR = getattr(settings, 'SLICES_SLICE_OVERLAY_DIR', 'overlay')
+
+SLICES_SLICE_OVERLAY_NAME = getattr(settings, 'SLICES_SLICE_OVERLAY_NAME',
+        'slice-%(pk)d-%(original)s')
+
+SLICES_SLICE_OVERLAY_EXTENSIONS = getattr(settings, 'SLICES_SLICE_OVERLAY_EXTENSIONS',
+        ('.tar.gz', '.tgz'))
+
 SLICES_SLIVER_EXP_DATA_DIR = getattr(settings, 'SLICES_SLIVER_EXP_DATA_DIR', 'exp_data')
 
 SLICES_SLIVER_EXP_DATA_NAME = getattr(settings, 'SLICES_SLIVER_EXP_DATA_NAME',
@@ -43,6 +53,13 @@ SLICES_SLIVER_EXP_DATA_NAME = getattr(settings, 'SLICES_SLIVER_EXP_DATA_NAME',
 SLICES_SLIVER_EXP_DATA_EXTENSIONS = getattr(settings, 'SLICES_SLIVER_EXP_DATA_EXTENSIONS',
         ('.tar.gz', '.tgz'))
 
+SLICES_SLIVER_OVERLAY_DIR = getattr(settings, 'SLICES_SLICE_OVERLAY_DIR', 'overlay')
+
+SLICES_SLIVER_OVERLAY_NAME = getattr(settings, 'SLICES_SLICE_EXP_DATA_NAME',
+        'slice-%(pk)d-%(original)s')
+
+SLICES_SLIVER_OVERLAY_EXTENSIONS = getattr(settings, 'SLICES_SLICE_EXP_DATA_EXTENSIONS',
+        ('.tar.gz', '.tgz'))
 
 
 # 30 days expiration interval
