@@ -28,6 +28,9 @@ class Group(models.Model):
                       'instantiated (false by default). Its value can only be changed '
                       'by testbed superusers.')
     
+    class Meta:
+        ordering = ['name']
+    
     def __unicode__(self):
         return self.name
     
@@ -152,6 +155,9 @@ class User(auth_models.AbstractBaseUser):
     USERNAME_FIELD = 'username'
     REQUIRED_FIELDS = ['email']
     
+    class Mate:
+        ordering = ['username']
+    
     def __unicode__(self):
         return self.username
     
